Crate ecgen

Crate ecgen 

ecgen-rs: Enumerative Combinatorics Generation

A library for generating combinatorial structures like permutations, combinations, set partitions, and binary Gray codes.

Features

  • std (default): Enables standard library support and logging

Logging

When the std feature is enabled, you can use the logging module:

use ecgen::logging::init_logger;

init_logger();
log::info!("Application started");

Set the RUST_LOG environment variable to control log level:

RUST_LOG=debug cargo run --features std

Re-exports

pub use crate::combin::comb;
pub use crate::combin::emk_comb_gen;
pub use crate::gray_code::brgc_gen;
pub use crate::perm::ehr_gen;
pub use crate::perm::factorial;
pub use crate::perm::sjt2;
pub use crate::perm::sjt_gen;
pub use crate::set_bipart::set_bipart_gen;
pub use crate::set_bipart::stirling2nd2;
pub use crate::set_partition::set_partition_gen;
pub use crate::set_partition::stirling2nd;

Modules

combin
Combination generation
combin_old
gray_code
Gray code generation
logging
Logging utilities for ecgen-rs
perm
Permutation generation
set_bipart
Set bipartition generation
set_partition
Set Partition Generator
set_partition_old